Module ci_manager::ci_provider::github::util
source · Expand description
Contains the ErrorLog struct describing a failed job log from GitHub Actions.
Structs
Functions
- Extracts the error logs from the logs, failed jobs and failed steps and returns a vector of JobErrorLog.
- Logs the job error logs to the info log in a readable summary