Structs

  • Type representing a date in the format YYYY-MM-DD.

Enums

  • Filter an element by its creation or update date.
  • Filter an element by its labels. This is a type-safe way to create a filter string for the GitHub API.

Functions