Enum ci_manager::config::commands::StepKind
source · pub enum StepKind {
Yocto,
Other,
}Expand description
The kind of step in CI, e.g. Yocto, Pytest, Pre-commit, Docker build, etc.
This is used to take highly specific actions based on the kind of CI step that failed. e.g. if a Yocto build fails, we can locate the specific log of the failed task and create a GitHub issue with the log attached, or pass it to another tool for uploading it etc.
Variants