Struct ci_manager::config::Config
source · pub struct Config { /* private fields */ }Implementations
sourceimpl Config
impl Config
sourcepub fn generate_completion_script(&self) -> bool
pub fn generate_completion_script(&self) -> bool
Generate completion scripts for the specified shell, returns true if a shell was specified meaning the user wants to generate a completion script
sourcepub fn no_ci(&self) -> Option<CIProvider>
pub fn no_ci(&self) -> Option<CIProvider>
Get the CI provider override
sourcepub fn trim_timestamp(&self) -> bool
pub fn trim_timestamp(&self) -> bool
Get the trim timestamp flag
sourcepub fn trim_ansi_codes(&self) -> bool
pub fn trim_ansi_codes(&self) -> bool
Get the trim ansi codes flag