Module ci_manager::util
source · Expand description
Utility functions for parsing and working with GitHub CLI output and other utility functions.
Functions
- Canonicalize a repository URL to the form
https://{host}/{repo} - Add https:// to a URL if it is not already present
- Parse an absolute path from a string. This assumes that the the first ‘/’ found in the string is the start of the path.
- Parse a path from a string
- Extract the job IDs from the lines with job information
- Calculate the smallest levenshtein distance between an issue body and other issue bodies
- Parse a log and remove line-prefixed timestamps in the format
YYYY-MM-DDTHH:MM:SS.0000000Z(ISO 8601). - Parse text for timestamps and IDs and remove them, returning the modified text without making a copy.
- Parse a repository URL/identifier to owner and repo fragments
- Take the lines with failed jobs from the output of
gh run view