Module ci_manager::ci_provider::github::util
source · Expand description
Contains the ErrorLog struct describing a failed job log from GitHub Actions.
Structs
Functions
- Logs the job error logs to the info log in a readable summary